@@ -4,11 +4,3 @@ pub fn divide_ternary_sizes(size: usize) -> (usize, usize, usize) {
 
   (group_size, group_size + extra, group_size)
 }
-
-pub fn rough_int_pow(x: usize, times: u16) -> usize {
-  if times < 1 {
-    return x;
-  }
-
-  x.pow(times as u32)
-}
